@@ -339,7 +339,7 @@ namespace eval ::db {
 	#	-dbname name	Name of database to retrieve from.
 	#	-fields list	List of fields to return  -OR-
 	#	-field str	Field to return
-	#	-all		Boolean conditional to return all or just one.
+	#	?-all?		Boolean conditional to return all or just one.
 	#	?-where cond?	Conditions to decide where to read.
 	# Rets: The value of the variable
 	# Stat: Complete
@@ -354,7 +354,7 @@ namespace eval ::db {
 			return -code error "error: You may only specify one of -field or -fields."
 		}
 		if {$dbnameidx == 0 || ($fieldsidx == 0 && $fieldidx == 0)} {
-			return -code error "error: You must specify -dbname and -fields."
+			return -code error "error: You must specify -dbname and -fields/-field."
 		}
 
 		if {$whereidx != 0} {
@@ -367,15 +367,15 @@ namespace eval ::db {
 
 		if {$fieldsidx != 0} {
 			::set fields [lindex $args $fieldsidx]
-			::set fieldstr [join $fields {, }]
 			::set selmode "-list"
 		}
 		if {$fieldidx != 0} {
-			::set fields [lindex $args $fieldidx]
-			::set fieldstr $fields
+			::set fields [list [lindex $args $fieldidx]]
 			::set selmode "-flatlist"
 		}
 
+		::set fieldstr [join $fields {, }]
+
 		::set dbname [lindex $args $dbnameidx]
 
 		if {[info exists where]} {
